@@ -147,12 +147,29 @@ public class GlyphSequence implements Cloneable {
     /**
      * Obtain the number of characters in character array, where
      * each character constitutes a unicode scalar value.
+     * NB: Supplementary characters (non-BMP code points) count as 1
+     * character, not as two UTF-16 code units.
      * @return number of characters available in character array
      */
     public int getCharacterCount() {
         return characters.limit();
     }
 
+    /**
+     * Obtain the number of characters in character array, where
+     * each character constitutes a UTF-16 character. This means
+     * that every non-BMP character is counted as 2 characters.
+     * @return number of chars (UTF-16 code units) available in
+     * character array
+     */
+    public int getUTF16CharacterCount() {
+        int count = 0;
+        for (int ch : characters.array()) {
+            count += Character.charCount(ch);
+        }
+        return count;
+    }
+
     /**
      * Obtain glyph id at specified index.
      * @param index to obtain glyph
@@ -303,7 +320,7 @@ public class GlyphSequence implements Cloneable {
     }
 
     /**
-     * Set predication <KEY,VALUE> at glyph sequence OFFSET.
+     * Set predication &lt;KEY,VALUE&gt; at glyph sequence OFFSET.
      * @param offset offset (index) into glyph sequence
      * @param key predication key
      * @param value predication value
